==> albert_0.27.0.orig.tar.gz: albert-0.27.0/i18n/albert.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>App</name>
    <message>
        <source>Failed to set the hotkey &apos;%1&apos;</source>
        <translation></translation>
    </message>
    <message>
        <source>Show/Hide</source>
        <translation></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation></translation>
    </message>
    <message>
        <source>Open website</source>
        <translation></translation>
    </message>
    <message>
        <source>Restart</source>
        <translation></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation></translation>
    </message>
    <message>
        <source>Changing the frontend requires a restart. Do you want to restart Albert?</source>
        <translation></translation>
    </message>
    <message>
        <source>This is the first time you&apos;ve launched Albert. Albert is plugin based. You have to enable some plugins you want to use.</source>
        <translation></translation>
    </message>
    <message>
        <source>You are now using Albert %1. The major version changed. Some parts of the API might have changed. Check the &lt;a href=&quot;https://albertlauncher.github.io/news/&quot;&gt;news&lt;/a&gt;.</source>
        <translation></translation>
    </message>
    <message>
        <source>Set the plugin dirs to use. Comma separated.</source>
        <translation></translation>
    </message>
    <message>
        <source>directories</source>
        <translation></translation>
    </message>
    <message>
        <source>RPC command to send to the running instance.</source>
        <translation></translation>
    </message>
    <message>
        <source>[command [params...]]</source>
        <translation></translation>
    </message>
    <message>
        <source>Print report and quit.</source>
        <translation></translation>
    </message>
    <message>
        <source>command</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch Albert or control a running instance.</source>
        <translation></translation>
    </message>
    <message>
        <source>Do not implicitly load enabled plugins.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AppQueryHandler</name>
    <message>
        <source>Settings</source>
        <translation></translation>
    </message>
    <message>
        <source>Albert settings</source>
        <translation></translation>
    </message>
    <message>
        <source>Open</source>
        <translation></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation></translation>
    </message>
    <message>
        <source>Quit Albert</source>
        <translation></translation>
    </message>
    <message>
        <source>Restart</source>
        <translation></translation>
    </message>
    <message>
        <source>Restart Albert</source>
        <translation></translation>
    </message>
    <message>
        <source>Cache location</source>
        <translation></translation>
    </message>
    <message>
        <source>Albert cache location</source>
        <translation></translation>
    </message>
    <message>
        <source>Config location</source>
        <translation></translation>
    </message>
    <message>
        <source>Albert config location</source>
        <translation></translation>
    </message>
    <message>
        <source>Data location</source>
        <translation></translation>
    </message>
    <message>
        <source>Albert data location</source>
        <translation></translation>
    </message>
    <message>
        <source>Control the app</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>FallbacksModel</name>
    <message>
        <source>Name</source>
        <translation></translation>
    </message>
    <message>
        <source>Description</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <source>Invalid plugin id. Use [a-z0-9_].</source>
        <translation></translation>
    </message>
    <message>
        <source>Plugin is invalid.</source>
        <translation></translation>
    </message>
    <message>
        <source>Plugin is unloaded.</source>
        <translation></translation>
    </message>
    <message>
        <source>Plugin is loaded.</source>
        <translation></translation>
    </message>
    <message>
        <source>Plugin is busy: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Loading…</source>
        <translation></translation>
    </message>
    <message>
        <source>Root extension registration failed: &apos;%1&apos;</source>
        <translation></translation>
    </message>
    <message>
        <source>Load: %1 ms, Instanciate: %2 ms</source>
        <translation></translation>
    </message>
    <message>
        <source>Unknown exception occurred.</source>
        <translation></translation>
    </message>
    <message>
        <source>Unloading…</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PluginQueryHandler</name>
    <message>
        <source>Loaded</source>
        <translation></translation>
    </message>
    <message>
        <source>Unloaded</source>
        <translation></translation>
    </message>
    <message>
        <source>Configuration</source>
        <translation></translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation></translation>
    </message>
    <message>
        <source>State</source>
        <translation></translation>
    </message>
    <message>
        <source>Open settings</source>
        <translation></translation>
    </message>
    <message>
        <source>Disable</source>
        <translation></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation></translation>
    </message>
    <message>
        <source>Unload</source>
        <translation></translation>
    </message>
    <message>
        <source>Reload</source>
        <translation></translation>
    </message>
    <message>
        <source>Load</source>
        <translation></translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation></translation>
    </message>
    <message>
        <source>Manage plugins</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PluginRegistry</name>
    <message>
        <source>Enabling &apos;%1&apos; will also enable the following plugins:</source>
        <translation></translation>
    </message>
    <message>
        <source>Disabling &apos;%1&apos; will also disable the following plugins:</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <source>Failed loading plugins</source>
        <translation>
            <numerusform>Failed loading plugin</numerusform>
            <numerusform>Failed loading plugins</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Failed unloading plugins</source>
        <translation>
            <numerusform>Failed unloading plugin</numerusform>
            <numerusform>Failed unloading plugins</numerusform>
        </translation>
    </message>
    <message>
        <source>Cyclic or missing dependencies detected:</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PluginWidget</name>
    <message>
        <source>Credits: %1</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <source>Required executables: %1</source>
        <translation>
            <numerusform>Required executable: %1</numerusform>
            <numerusform>Required executables: %1</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Required libraries: %1</source>
        <translation>
            <numerusform>Required library: %1</numerusform>
            <numerusform>Required libraries: %1</numerusform>
        </translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <source>Authors: %1</source>
        <translation>
            <numerusform>Author: %1</numerusform>
            <numerusform>Authors: %1</numerusform>
        </translation>
    </message>
    <message>
        <source>Requires: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Required by: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Translations: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>%1, Interface: %2</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PluginsWidget</name>
    <message>
        <source>Select a plugin</source>
        <translation></translation>
    </message>
    <message>
        <source>Disable</source>
        <translation></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation></translation>
    </message>
    <message>
        <source>Unload</source>
        <translation></translation>
    </message>
    <message>
        <source>Load</source>
        <translation></translation>
    </message>
    <message>
        <source>Enabled first</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QHotKeyDialog</name>
    <message>
        <source>Set hotkey</source>
        <translation></translation>
    </message>
    <message>
        <source>Press a key combination</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QtPluginLoader</name>
    <message>
        <source>Invalid interface identifier (IID) pattern : &apos;%1&apos;. Expected &apos;%2&apos;.</source>
        <translation></translation>
    </message>
    <message>
        <source>Incompatible major version: %1. Expected: %2.</source>
        <translation></translation>
    </message>
    <message>
        <source>Incompatible minor version: %1. Supported up to: %2.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QtPluginProvider</name>
    <message>
        <source>Loads native C++ plugins</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QueryHandlerModel</name>
    <message>
        <source>This extension does not allow trigger remapping.</source>
        <translation></translation>
    </message>
    <message>
        <source>Trigger &apos;%1&apos; is reserved for &apos;%2&apos;.</source>
        <translation></translation>
    </message>
    <message>
        <source>Disable global query handler.</source>
        <translation></translation>
    </message>
    <message>
        <source>Enable global query handler.</source>
        <translation></translation>
    </message>
    <message>
        <source>Disable fuzzy matching.</source>
        <translation></translation>
    </message>
    <message>
        <source>Enable fuzzy matching.</source>
        <translation></translation>
    </message>
    <message>
        <source>Extension</source>
        <translation></translation>
    </message>
    <message>
        <source>Trigger</source>
        <translation></translation>
    </message>
    <message>
        <source>G</source>
        <comment>short Global</comment>
        <translation></translation>
    </message>
    <message>
        <source>F</source>
        <comment>short Fuzzy</comment>
        <translation></translation>
    </message>
    <message>
        <source>The trigger of the handler. Spaces are visualized by •.</source>
        <translation></translation>
    </message>
    <message>
        <source>Enabled global query handlers.</source>
        <translation></translation>
    </message>
    <message>
        <source>Fuzzy matching.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QueryWidget</name>
    <message>
        <source>Fallback order</source>
        <translation></translation>
    </message>
    <message>
        <source>Sort perference</source>
        <translation></translation>
    </message>
    <message>
        <source>Prefer most frequently used results.</source>
        <translation></translation>
    </message>
    <message>
        <source>MFU</source>
        <translation></translation>
    </message>
    <message>
        <source>This preference determines how past activations influence the ranking of the results of a query.
Using MFU all activations get the same weight and the cumulated score of a results is the count of its usages.
Using MRU the sum of weights of past activations can not exceed those of newer ones.
Recommended is a value in between, such that the results you use often are preferred while still allowing Albert to adapt to changes in your usage habits.</source>
        <translation></translation>
    </message>
    <message>
        <source>Prefer most recently used results.</source>
        <translation></translation>
    </message>
    <message>
        <source>MRU</source>
        <translation></translation>
    </message>
    <message>
        <source>Prioritize perfect matches</source>
        <translation></translation>
    </message>
    <message>
        <source>Prioritize perfect matches even if they have no usage history and therefore would have a lower rank.</source>
        <translation></translation>
    </message>
    <message>
        <source>Query handlers</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SettingsWindow</name>
    <message>
        <source>Settings</source>
        <translation></translation>
    </message>
    <message>
        <source>General</source>
        <translation></translation>
    </message>
    <message>
        <source>Frontend</source>
        <translation></translation>
    </message>
    <message>
        <source>Show tray icon</source>
        <translation></translation>
    </message>
    <message>
        <source>Join the community on [Telegram](%1) or [Discord](%2).</source>
        <translation></translation>
    </message>
    <message>
        <source>Credits:</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Plugins</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Query</source>
        <translation></translation>
    </message>
    <message>
        <source>Not set</source>
        <translation></translation>
    </message>
    <message>
        <source>Not supported</source>
        <translation></translation>
    </message>
    <message>
        <source>Hotkey</source>
        <translation></translation>
    </message>
    <message>
        <source>Telemetry</source>
        <translation></translation>
    </message>
    <message>
        <source>Support Albert with a [donation](%1)&lt;br/&gt;or by becoming a [GitHub sponsor](%2).</source>
        <translation></translation>
    </message>
    <message>
        <source>Report bugs on [GitHub](%1).</source>
        <translation></translation>
    </message>
    <message>
        <source>Written in C++, powered by [Qt](aboutQt).</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Telemetry</name>
    <message>
        <source>Telemetry helps improving the user experience by collecing anonymous data. You can review the telemetry data to be sent in the settings. Do you want to enable telemetry? This configuration be changed at any time in the settings.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>TriggersQueryHandler</name>
    <message>
        <source>Trigger completion items.</source>
        <translation></translation>
    </message>
</context>
</TS>

==> albert_0.27.3.orig.tar.gz: albert-0.27.3/i18n/albert.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>App</name>
    <message>
        <source>Failed to set the hotkey &apos;%1&apos;</source>
        <translation></translation>
    </message>
    <message>
        <source>Show/Hide</source>
        <translation></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation></translation>
    </message>
    <message>
        <source>Open website</source>
        <translation></translation>
    </message>
    <message>
        <source>Restart</source>
        <translation></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation></translation>
    </message>
    <message>
        <source>Changing the frontend requires a restart. Do you want to restart Albert?</source>
        <translation></translation>
    </message>
    <message>
        <source>This is the first time you&apos;ve launched Albert. Albert is plugin based. You have to enable some plugins you want to use.</source>
        <translation></translation>
    </message>
    <message>
        <source>You are now using Albert %1. The major version changed. Some parts of the API might have changed. Check the &lt;a href=&quot;https://albertlauncher.github.io/news/&quot;&gt;news&lt;/a&gt;.</source>
        <translation></translation>
    </message>
    <message>
        <source>Set the plugin dirs to use. Comma separated.</source>
        <translation></translation>
    </message>
    <message>
        <source>directories</source>
        <translation></translation>
    </message>
    <message>
        <source>RPC command to send to the running instance.</source>
        <translation></translation>
    </message>
    <message>
        <source>[command [params...]]</source>
        <translation></translation>
    </message>
    <message>
        <source>Print report and quit.</source>
        <translation></translation>
    </message>
    <message>
        <source>command</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch Albert or control a running instance.</source>
        <translation></translation>
    </message>
    <message>
        <source>Do not implicitly load enabled plugins.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AppQueryHandler</name>
    <message>
        <source>Settings</source>
        <translation></translation>
    </message>
    <message>
        <source>Albert settings</source>
        <translation></translation>
    </message>
    <message>
        <source>Open</source>
        <translation></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation></translation>
    </message>
    <message>
        <source>Quit Albert</source>
        <translation></translation>
    </message>
    <message>
        <source>Restart</source>
        <translation></translation>
    </message>
    <message>
        <source>Restart Albert</source>
        <translation></translation>
    </message>
    <message>
        <source>Cache location</source>
        <translation></translation>
    </message>
    <message>
        <source>Albert cache location</source>
        <translation></translation>
    </message>
    <message>
        <source>Config location</source>
        <translation></translation>
    </message>
    <message>
        <source>Albert config location</source>
        <translation></translation>
    </message>
    <message>
        <source>Data location</source>
        <translation></translation>
    </message>
    <message>
        <source>Albert data location</source>
        <translation></translation>
    </message>
    <message>
        <source>Control the app</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Dependency</name>
    <message>
        <source>Extension &apos;%1&apos; is available, but it is not of the expected type.</source>
        <translation></translation>
    </message>
    <message>
        <source>The required extension &apos;%1&apos; is not available.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>FallbacksModel</name>
    <message>
        <source>Name</source>
        <translation></translation>
    </message>
    <message>
        <source>Description</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <source>Invalid plugin id. Use [a-z0-9_].</source>
        <translation></translation>
    </message>
    <message>
        <source>Plugin is invalid.</source>
        <translation></translation>
    </message>
    <message>
        <source>Plugin is unloaded.</source>
        <translation></translation>
    </message>
    <message>
        <source>Plugin is loaded.</source>
        <translation></translation>
    </message>
    <message>
        <source>Plugin is busy: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Loading…</source>
        <translation></translation>
    </message>
    <message>
        <source>Load: %1 ms, Instanciate: %2 ms</source>
        <translation></translation>
    </message>
    <message>
        <source>Unknown exception occurred.</source>
        <translation></translation>
    </message>
    <message>
        <source>Unloading…</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PluginQueryHandler</name>
    <message>
        <source>Loaded</source>
        <translation></translation>
    </message>
    <message>
        <source>Unloaded</source>
        <translation></translation>
    </message>
    <message>
        <source>Configuration</source>
        <translation></translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation></translation>
    </message>
    <message>
        <source>State</source>
        <translation></translation>
    </message>
    <message>
        <source>Open settings</source>
        <translation></translation>
    </message>
    <message>
        <source>Disable</source>
        <translation></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation></translation>
    </message>
    <message>
        <source>Unload</source>
        <translation></translation>
    </message>
    <message>
        <source>Reload</source>
        <translation></translation>
    </message>
    <message>
        <source>Load</source>
        <translation></translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation></translation>
    </message>
    <message>
        <source>Manage plugins</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PluginRegistry</name>
    <message>
        <source>Enabling &apos;%1&apos; will also enable the following plugins:</source>
        <translation></translation>
    </message>
    <message>
        <source>Disabling &apos;%1&apos; will also disable the following plugins:</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <source>Failed loading plugins</source>
        <translation>
            <numerusform>Failed loading plugin</numerusform>
            <numerusform>Failed loading plugins</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Failed unloading plugins</source>
        <translation>
            <numerusform>Failed unloading plugin</numerusform>
            <numerusform>Failed unloading plugins</numerusform>
        </translation>
    </message>
    <message>
        <source>Cyclic or missing dependencies detected:</source>
        <translation></translation>
    </message>
    <message>
        <source>Check the log for more information.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PluginWidget</name>
    <message>
        <source>Credits: %1</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <source>Required executables: %1</source>
        <translation>
            <numerusform>Required executable: %1</numerusform>
            <numerusform>Required executables: %1</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Required libraries: %1</source>
        <translation>
            <numerusform>Required library: %1</numerusform>
            <numerusform>Required libraries: %1</numerusform>
        </translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <source>Authors: %1</source>
        <translation>
            <numerusform>Author: %1</numerusform>
            <numerusform>Authors: %1</numerusform>
        </translation>
    </message>
    <message>
        <source>Requires: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Required by: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>Translations: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>%1, Interface: %2</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PluginsWidget</name>
    <message>
        <source>Disable</source>
        <translation></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation></translation>
    </message>
    <message>
        <source>Unload</source>
        <translation></translation>
    </message>
    <message>
        <source>Load</source>
        <translation></translation>
    </message>
    <message>
        <source>Enabled first</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;p&gt;Plugins are a community effort,&lt;br&gt;built by awesome people like you.&lt;/p&gt;&lt;p&gt;💡 &lt;a href=&apos;https://albertlauncher.github.io/gettingstarted/extension/&apos;&gt;Learn how to build plugins&lt;/a&gt;&lt;/p&gt;&lt;br&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QHotkey</name>
    <message>
        <source>Failed to register %1. Error: %2</source>
        <translation></translation>
    </message>
    <message>
        <source>Failed to unregister %1. Error: %2</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QtPluginLoader</name>
    <message>
        <source>Invalid interface identifier (IID) pattern : &apos;%1&apos;. Expected &apos;%2&apos;.</source>
        <translation></translation>
    </message>
    <message>
        <source>Incompatible major version: %1. Expected: %2.</source>
        <translation></translation>
    </message>
    <message>
        <source>Incompatible minor version: %1. Supported up to: %2.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QtPluginProvider</name>
    <message>
        <source>Loads native C++ plugins</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QueryHandlerModel</name>
    <message>
        <source>This extension does not allow trigger remapping.</source>
        <translation></translation>
    </message>
    <message>
        <source>Trigger &apos;%1&apos; is reserved for &apos;%2&apos;.</source>
        <translation></translation>
    </message>
    <message>
        <source>Disable global query handler.</source>
        <translation></translation>
    </message>
    <message>
        <source>Enable global query handler.</source>
        <translation></translation>
    </message>
    <message>
        <source>Disable fuzzy matching.</source>
        <translation></translation>
    </message>
    <message>
        <source>Enable fuzzy matching.</source>
        <translation></translation>
    </message>
    <message>
        <source>Extension</source>
        <translation></translation>
    </message>
    <message>
        <source>Trigger</source>
        <translation></translation>
    </message>
    <message>
        <source>G</source>
        <comment>short Global</comment>
        <translation></translation>
    </message>
    <message>
        <source>F</source>
        <comment>short Fuzzy</comment>
        <translation></translation>
    </message>
    <message>
        <source>The trigger of the handler. Spaces are visualized by •.</source>
        <translation></translation>
    </message>
    <message>
        <source>Enabled global query handlers.</source>
        <translation></translation>
    </message>
    <message>
        <source>Fuzzy matching.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QueryWidget</name>
    <message>
        <source>Fallback order</source>
        <translation></translation>
    </message>
    <message>
        <source>Sort perference</source>
        <translation></translation>
    </message>
    <message>
        <source>Prefer most frequently used results.</source>
        <translation></translation>
    </message>
    <message>
        <source>MFU</source>
        <translation></translation>
    </message>
    <message>
        <source>This preference determines how past activations influence the ranking of the results of a query.
Using MFU all activations get the same weight and the cumulated score of a results is the count of its usages.
Using MRU the sum of weights of past activations can not exceed those of newer ones.
Recommended is a value in between, such that the results you use often are preferred while still allowing Albert to adapt to changes in your usage habits.</source>
        <translation></translation>
    </message>
    <message>
        <source>Prefer most recently used results.</source>
        <translation></translation>
    </message>
    <message>
        <source>MRU</source>
        <translation></translation>
    </message>
    <message>
        <source>Prioritize perfect matches</source>
        <translation></translation>
    </message>
    <message>
        <source>Prioritize perfect matches even if they have no usage history and therefore would have a lower rank.</source>
        <translation></translation>
    </message>
    <message>
        <source>Query handlers</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SettingsWindow</name>
    <message>
        <source>Settings</source>
        <translation></translation>
    </message>
    <message>
        <source>General</source>
        <translation></translation>
    </message>
    <message>
        <source>Frontend</source>
        <translation></translation>
    </message>
    <message>
        <source>Show tray icon</source>
        <translation></translation>
    </message>
    <message>
        <source>Join the community on [Telegram](%1) or [Discord](%2).</source>
        <translation></translation>
    </message>
    <message>
        <source>Credits:</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Plugins</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Query</source>
        <translation></translation>
    </message>
    <message>
        <source>Not set</source>
        <translation></translation>
    </message>
    <message>
        <source>Not supported</source>
        <translation></translation>
    </message>
    <message>
        <source>Hotkey</source>
        <translation></translation>
    </message>
    <message>
        <source>Telemetry</source>
        <translation></translation>
    </message>
    <message>
        <source>Support Albert with a [donation](%1)&lt;br/&gt;or by becoming a [GitHub sponsor](%2).</source>
        <translation></translation>
    </message>
    <message>
        <source>Report bugs on [GitHub](%1).</source>
        <translation></translation>
    </message>
    <message>
        <source>Written in C++, powered by [Qt](aboutQt).</source>
        <translation></translation>
    </message>
    <message>
        <source>Set hotkey</source>
        <translation></translation>
    </message>
    <message>
        <source>Press a key combination</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Telemetry</name>
    <message>
        <source>Telemetry helps improving the user experience by collecing anonymous data. You can review the telemetry data to be sent in the settings. Do you want to enable telemetry? This configuration can be changed at any time in the settings.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>TriggersQueryHandler</name>
    <message>
        <source>Trigger completion items.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>albert</name>
    <message>
        <source>Failed creating directory %1: %2</source>
        <translation></translation>
    </message>
</context>
</TS>
